@@ -85,9 +85,9 @@ static char *function_names[NUM_FUNCTIONS + 1] = {
    "Exchange", "Copy", "Move", "Join", "Unjoin", "Spline", "Edit",
    "Undo", "Redo", "Select Save", "Unselect", "Dashed", "Dotted",
    "Solid", "Prompt", "Dot", "Wire", "Start", "Finish", "Cancel",
-   "Nothing", "Exit",
-   "Netlist", "Swap", "Pin Label", "Pin Global", "Info Label",
-   "Connectivity", "Sim", "SPICE", "PCB", "SPICE Flat",
+   "Nothing", "Exit", "Netlist", "Swap", "Pin Label", "Pin Global",
+   "Info Label", "Graphic", "Rescale", "Connectivity", "Sim", "SPICE",
+   "PCB", "SPICE Flat",
    NULL			/* sentinel */
 };
 
