@@ -596,6 +596,9 @@ extern Genericlist *pintonet(objectptr, objinstptr, labelptr);
 extern Genericlist *nametonet(objectptr, objinstptr, char *);
 extern Genericlist *new_tmp_pin(objectptr, XPoint *, char *, char *, Genericlist *);
 extern Genericlist *make_tmp_pin(objectptr, objinstptr, XPoint *, Genericlist *);
+extern void resolve_devnames(objectptr);
+extern void resolve_indices(objectptr, Boolean);
+extern void clear_indices(objectptr);
 extern char *parseinfo(objectptr, CalllistPtr, char *, char *, Boolean);
 extern int writedevice(FILE *, char *, objectptr, CalllistPtr, char *);
 extern void writeflat(objectptr, CalllistPtr, char *, FILE *, char *);
@@ -608,7 +611,7 @@ extern void freepcb(struct Ptab *);
 extern void freegenlist(Genericlist *);
 extern void freepolylist(PolylistPtr *);
 extern void freelabellist(LabellistPtr *);
-extern void freeports(CalllistPtr);
+extern void freecalls(CalllistPtr);
 extern void freenets(objectptr);
 extern void freetemplabels(objectptr);
 extern void freeglobals();
@@ -777,6 +780,7 @@ extern stringpart *splitstring(int, stringpart **, objinstptr);
 extern stringpart *mergestring(stringpart *);
 extern stringpart *linkstring(objinstptr, stringpart *, Boolean);
 extern int findcurfont(int, stringpart *, objinstptr);
+extern stringpart *findtextinstring(char *, int *, stringpart *, objinstptr);
 extern stringpart *findstringpart(int, int *, stringpart *, objinstptr);
 extern void charprint(char *, stringpart *, int);
 extern char *stringprint(stringpart *, objinstptr);
