@@ -273,7 +273,7 @@ stringpart *deletestring(stringpart *dstr, stringpart **strtop, objinstptr thisi
       /* out if it's an instance or a default, and change the pointer	*/
       /* to the parameter in the parameter list, accordingly.		*/
 
-      else if (strptr->type == PARAM_START) {
+      else if ((strptr->type == PARAM_START) && (thisinst != NULL)) {
 	 key = strptr->data.string;
 	 ops = find_param(thisinst, key);
 	 if (ops == NULL) {
@@ -450,6 +450,34 @@ int findcurfont(int tpos, stringpart *strtop, objinstptr thisinst)
    return cfont;
 }
 
+/*----------------------------------------------------------------------*/
+/* Return a local position and stringpart for the first occurrence of	*/
+/* "substring" in the the indicated xcircuit string.  If non-NULL,	*/
+/* "locpos" is set to the position of the substring in the stringpart,	*/
+/* or -1 if the text was not found.  Text cannot cross stringpart	*/
+/* boundaries (although this should be allowed).			*/
+/*----------------------------------------------------------------------*/
+
+stringpart *findtextinstring(char *search, int *locpos, stringpart *strtop,
+	objinstptr localinst)
+{
+   stringpart *strptr = strtop;
+   char *strstart;
+
+   for (strptr = strtop; strptr != NULL; strptr = nextstringpart(strptr, localinst)) {
+      if ((strptr->type == TEXT_STRING) && strptr->data.string) {
+	 strstart = strstr(strptr->data.string, search);
+	 if (strstart != NULL) {
+	    if (locpos != NULL)
+	       *locpos = (int)(strstart - (char *)strptr->data.string);
+	    return strptr;
+	 }
+      }
+   }
+   if (locpos != NULL) *locpos = -1;
+   return NULL;
+}
+
 /*----------------------------------------------------------------------*/
 /* Return a local position and stringpart for "tpos" positions into	*/
 /* the indicated string.  Position and stringpart are for the character */
@@ -1722,7 +1750,7 @@ TextExtents ULength(stringpart *string, objinstptr localinst, float newscale,
 
 void undrawtextsimple(labelptr settext)
 {
-   XSetFunction(dpy, areastruct.gc, GXcopy);
+   SetFunction(dpy, areastruct.gc, GXcopy);
    XTopSetForeground(BACKGROUND);
    UDrawString(settext, DOFORALL, areastruct.topinstance);
 }
