@@ -291,7 +291,7 @@ CATPAN_MODE, CATALOG_MODE, CATTEXT_MODE, FONTCAT_MODE, FONTCAT2_MODE,
 TEXT1_MODE, TEXT2_MODE, TEXT3_MODE, WIRE_MODE, POLY_MODE, BOX0_MODE,
 BOX_MODE, EBOX_MODE, ARC0_MODE, ARC_MODE, EARC_MODE, SPLINE0_MODE,
 SPLINE_MODE, ESPLINE_MODE, EPATH_MODE, LPARAM_MODE, IPARAM_MODE,
-ULPARAM_MODE, UIPARAM_MODE, CONNECT_MODE, ASSOC_MODE};
+ULPARAM_MODE, UIPARAM_MODE, CONNECT_MODE, ASSOC_MODE, RESCALE_MODE};
 
 /*----------------------------------------------------------------------*/
 /* File loading modes							*/
@@ -838,7 +838,8 @@ typedef struct _Calllist
    objectptr   cschem;		/* Schematic containing the instance called */
    objinstptr  callinst;	/* Instance called */
    objectptr   callobj;		/* Object of instance called */
-   int         devindex;	/* if non-zero, index of device in netlist */
+   char	       *devname;	/* if non-null, name of device in netlist */
+   int         devindex;	/* if non-negative, index of device in netlist */
    PortlistPtr ports;
    CalllistPtr next;
 } Calllist;
@@ -891,7 +892,6 @@ typedef struct _xcobject {
    Highlight	highlight;	/* net to be highlighted on redraw */
    u_char	schemtype;
    objectptr	symschem;	/* schematic page support */
-   char		*devname;	/* if non-null, name of device in netlist */
    Boolean	valid;		/* Is current netlist valid? */
    Boolean	traversed;	/* Flag to indicate object was processed */
    LabellistPtr	labels;		/* Netlist pins	 */
@@ -1133,6 +1133,8 @@ typedef struct _keybinding {
 
 /*----------------------------------------------------------------------*/
 /* Enumeration of functions available for binding to keys/buttons	*/
+/* IMPORTANT!  Do not alter this list without also fixing the text	*/
+/* in keybindings.c!							*/
 /*----------------------------------------------------------------------*/
 
 enum {
@@ -1187,9 +1189,10 @@ enum {
    XCF_Exit /* 94 */,		XCF_Netlist /* 95 */,
    XCF_Swap /* 96 */,		XCF_Pin_Label /* 97 */,
    XCF_Pin_Global /* 98 */,	XCF_Info_Label /* 99 */,
-   XCF_Graphic	/* 100 */,	XCF_Connectivity /* 101 */,
-   XCF_Sim /* 102 */,		XCF_SPICE /* 103 */,
-   XCF_PCB /* 104 */,		XCF_SPICEflat /* 105 */,
+   XCF_Graphic	/* 100 */,	XCF_Rescale /* 101 */,
+   XCF_Connectivity /* 102 */,	XCF_Sim /* 103 */,
+   XCF_SPICE /* 104 */,		XCF_PCB /* 105 */,
+   XCF_SPICEflat /* 106 */,
    NUM_FUNCTIONS
 };
 
